class.kurt.moment.eng: Verbal Classification for Kurtosis
Description
This internal function generates the verbal classification for the kurtosis parameter calculated by gran.stats function according to Methods of Moments, in English language
Usage
class.kurt.moment.eng(kurtosis.moment)
Arguments
kurtosis.moment
a numeric object with length 1 which is classified