Learn R Programming

rysgran (version 1.0)

class.kurt.moment.pt: Verbal Classification for Skewness in Portuguese Language

Description

This internal function generates the verbal classification for the kurtosis parameter calculated by gran.stats function according to Methods of Moments, in Portuguese language

Usage

class.kurt.moment.pt(kurtosis.moment)

Arguments

kurtosis.moment
a numeric object with length 1 which is classified

Value

  • A character string with the verbal classification

See Also

gran.stats

Examples

Run this code
#Method of Moments with verbal classification
library(rysgran)
data(camargo2001)
tab<-camargo2001
gran.stats(tab , method="moment" , verbal=TRUE , lang="pt-BR")

Run the code above in your browser using DataLab