Learn R Programming

rysgran (version 1.0)

class.skew.moment.eng: Verbal Classification for Skewness

Description

This internal function generates the verbal classification for the skewness parameter calculated by gran.stats function according to Methods of Moments, in English language

Usage

class.skew.moment.eng(skewness.moment)

Arguments

skewness.moment
a numeric object with length 1 which is classified

Value

  • A character string with the verbal classification

See Also

gran.stats

Examples

Run this code
#Method of Moments with verbal classification
library(rysgran)
data(camargo2001)
tab<-camargo2001
gran.stats(tab , method="moment" , verbal=TRUE , lang="en-US")

Run the code above in your browser using DataLab