class.kurt.moment.pt: Verbal Classification for Skewness in Portuguese Language
Description
This internal function generates the verbal classification for the kurtosis parameter calculated by gran.stats function according to Methods of Moments, in Portuguese language
Usage
class.kurt.moment.pt(kurtosis.moment)
Arguments
kurtosis.moment
a numeric object with length 1 which is classified