class.skew.moment.eng: Verbal Classification for Skewness
Description
This internal function generates the verbal classification for the skewness parameter calculated by gran.stats function according to Methods of Moments, in English language
Usage
class.skew.moment.eng(skewness.moment)
Arguments
skewness.moment
a numeric object with length 1 which is classified